@@ -17,10 +17,10 @@ from dgspoc.usage import validate_usage
 # from dgspoc.usage import show_usage
 from dgspoc.usage import validate_example_usage
 
+from dgspoc.operation import do_clear_template
 from dgspoc.operation import do_build_template
 from dgspoc.operation import do_search_template
-from dgspoc.operation import do_test_template
-from dgspoc.operation import do_test_verification
+from dgspoc.operation import do_testing
 
 
 class ArgumentParser(argparse.ArgumentParser):
@@ -80,7 +80,9 @@ def show_info(options):
 
         if is_showed_all or is_showed_dependency:
             lst and lst.append('--------------------')
-            for pkg in Data.get_dependency().values():
+            lst.append('Packages:')
+            values = Data.get_dependency().values()
+            for pkg in sorted(values, key=lambda item: item.get('package')):
                 lst.append('  + Package: {0[package]}'.format(pkg))
                 lst.append('             {0[url]}'.format(pkg))
 
@@ -155,8 +157,8 @@ class Cli:
         ),
 
         parser.add_argument(
-            '--test-file', type=str, dest='testfile', default='',
-            help="test data file"
+            '--clear', type=str, dest='template_id', default='',
+            help="clear template from template-storage"
         ),
 
         parser.add_argument(
@@ -165,35 +167,15 @@ class Cli:
         ),
 
         parser.add_argument(
-            '--execution', type=str, default='',
-            help="command line"
+            '--action', type=str, default='',
+            help="execution action which uses to test template or verification"
         ),
 
-        parser.add_argument(
-            '--select-statement', type=str, default='', dest='stmt',
-            help='the select statement of verification'
-        )
-
         parser.add_argument(
             '--replaced', action='store_true',
             help='overwrite template ID/file'
         )
 
-        parser.add_argument(
-            '--ignore-case', action='store_true', dest='ignore_case',
-            help='case insensitive matching'
-        )
-
-        parser.add_argument(
-            '--showed', action='store_true',
-            help='showing result'
-        )
-
-        parser.add_argument(
-            '--tabular', action='store_true',
-            help='showing result in tabular format'
-        )
-
         parser.add_argument(
             '--all', action='store_true',
             help='showing all information'
@@ -253,11 +235,11 @@ class Cli:
         show_info(self.options)
 
         # operation
+        do_clear_template(self.options)
         do_build_template(self.options)
         do_search_template(self.options)
-        do_test_template(self.options)
 
-        do_test_verification(self.options)
+        do_testing(self.options)
 
 
 def execute():
