@@ -2,16 +2,30 @@
 
 import re
 
+import subprocess
+from copy import deepcopy
+
 from pathlib import Path
 from pathlib import PurePath
+from pathlib import WindowsPath
 from datetime import datetime
 
 from textwrap import wrap
 
+from argparse import ArgumentParser
+
 import yaml
 
 import typing
 
+from io import StringIO
+
+from textfsm import TextFSM
+
+from dgspoc.exceptions import UtilsParsedTemplateError
+
+from dgspoc.constant import ECODE
+
 
 class Text(str):
     def __new__(cls, *args, **kwargs):
@@ -180,8 +194,12 @@ class File:
         -------
         bool: True if existed, otherwise False
         """
-        file_obj = Path(filename)
-        return file_obj.exists()
+        try:
+            file_obj = Path(filename)
+            return file_obj.exists()
+        except Exception as ex:
+            cls.message = Text(ex)
+            return False
 
     @classmethod
     def create(cls, filename, showed=True):
@@ -276,22 +294,40 @@ class File:
             return ''
 
     @classmethod
-    def get_result_from_yaml_file(cls, file_path, default=dict(),   # noqa
-                                  is_stripped=True):
+    def get_result_from_yaml_file(cls, file_path, base_dir='',
+                                  is_stripped=True,
+                                  dot_datatype=False,
+                                  default=dict(),  # noqa
+                                  var_substitution=False,
+                                  root_var_name='self'
+                                  ):
         """get result of YAML file
 
         Parameters
         ----------
         file_path (string): file path
-        default (object): a default result file is not found.  Default is empty dict.
+        base_dir (str): a based directory
         is_stripped (bool): removing leading or trailing space.  Default is True.
+        dot_datatype (bool): convert a return_result to DotObject if
+                return_result is dictionary.  Default is False.
+        default (object): a default result file is not found.  Default is empty dict.
+        var_substitution (bool): internal variable substitution.  Default is False.
+        root_var_name (str): root variable of data structure for
+                variable substitution.  Default is self.
 
         Returns
         -------
         object: YAML result
         """
+
+        yaml_result = default
+
         try:
-            filename = cls.get_path(file_path)
+            if base_dir:
+                filename = cls.get_path(cls.get_dir(base_dir), file_path)
+            else:
+                filename = cls.get_path(file_path)
+
             with open(filename) as stream:
                 content = stream.read()
                 if is_stripped:
@@ -300,17 +336,25 @@ class File:
                 if content:
                     yaml_result = yaml.safe_load(content)
                     cls.message = 'loaded {}'.format(filename)
-                    return yaml_result
                 else:
                     cls.message = '"{}" file is empty.'.format(filename)
-                    return default
+
         except Exception as ex:
             cls.message = Text(ex)
-            return default
+
+        if var_substitution:
+            yaml_result = Misc.substitute_variable(yaml_result,
+                                                   root_var_name=root_var_name)
+
+        if Misc.is_dict(yaml_result) and dot_datatype:
+            dot_result = DotObject(yaml_result)
+            return dot_result
+        else:
+            return yaml_result
 
     @classmethod
     def save(cls, filename, data):
-        """Create a file path
+        """save data to file
 
         Parameters
         ----------
@@ -340,6 +384,47 @@ class File:
             cls.message = Text(ex)
             return False
 
+    @classmethod
+    def delete(cls, filename):
+        """Delete file
+
+        Parameters
+        ----------
+        filename (str): filename
+
+        Returns
+        -------
+        bool: True if successfully deleted, otherwise, False
+        """
+        try:
+            filepath = File.get_path(filename)
+            file_obj = Path(filepath)
+            if file_obj.is_dir():
+                file_obj.rmdir()
+            else:
+                file_obj.unlink()
+            cls.message = 'Successfully deleted "{}" file'.format(filename)
+            return True
+        except Exception as ex:
+            cls.message = Text(ex)
+            return False
+
+    @classmethod
+    def change_home_dir_to_generic(cls, filename):
+        """change HOME DIRECTORY in filename to generic name
+        ++++++++++++++++++++++++++++++++++++++++++++++
+        Note: this function only uses for displaying.
+        ++++++++++++++++++++++++++++++++++++++++++++++
+        """
+        node = Path.home()
+        home_dir = str(node)
+        if isinstance(node, WindowsPath):
+            replaced = '%HOMEDRIVE%\\%HOMEPATH%'
+        else:
+            replaced = '${HOME}'
+        new_name = filename.replace(home_dir, replaced)
+        return new_name
+
 
 class Misc:
 
@@ -463,6 +548,142 @@ class Misc:
             new_data = '\n'.join(data.splitlines()[1:])
             return new_data
 
+    @classmethod
+    def substitute_variable(cls, data, root_var_name='self'):
+        """substitute variable within data structure if there
+
+        Parameters
+        ----------
+        data (dict): a dictionary.
+        root_var_name (str): root variable of data structure for
+                variable substitution.  Default is self.
+
+        Returns
+        -------
+        dict: a new dictionary if substituted, otherwise, the given data.
+
+        """
+        def replace(txt, **kwargs):
+            if len(kwargs) == 1:
+                var_name = list(kwargs)[0]
+                pattern = r'(?i)[{]%s([.][a-z]\w*)+[}]' % var_name
+            else:
+                pattern = r'(?i)[{][a-z]\w*([.][a-z]\w*)+[}]'
+            lines = txt.splitlines()
+            for index, line in enumerate(lines):
+                if line.strip():
+                    lst = []
+                    start = 0
+                    for match in re.finditer(pattern, line):
+                        lst.append(line[start:match.start()])
+                        start = match.end()
+                        matched_result = match.group()
+                        try:
+                            val = matched_result.format(**kwargs)
+                            lst.append(val)
+                        except Exception as ex:     # noqa
+                            lst.append(matched_result)
+                    else:
+                        if lst:
+                            lst.append(line[start:])
+                            lines[index] = ''.join(lst)
+
+            new_txt = '\n'.join(lines)
+            return new_txt
+
+        def substitute(node, variables_):
+            if cls.is_dict(node):
+                for key, val in node.items():
+                    if cls.is_dict(val) or cls.is_list(val):
+                        substitute(val, variables_)
+                    else:
+                        if cls.is_string(val):
+                            new_val = replace(val, **variables_)
+                            node[key] = new_val
+            elif cls.is_list(node):
+                for index, item in enumerate(node):
+                    if cls.is_dict(item) or cls.is_list(item):
+                        substitute(item, variables_)
+                    else:
+                        if cls.is_string(item):
+                            new_item = item.format(obj=variables_)
+                            node[index] = new_item
+            else:
+                return
+
+        if not cls.is_dict(data):
+            return data
+
+        new_data = deepcopy(data)
+        variables = {root_var_name: DotObject(deepcopy(new_data))}
+        substitute(new_data, variables)
+        return new_data
+
+
+class MiscArgs:
+    @classmethod
+    def get_parsed_result_as_data_or_file(cls, *kwflags, data=''):
+        try:
+            parser = ArgumentParser(exit_on_error=False)
+        except Exception as ex:     # noqa
+            parser = ArgumentParser()
+
+        parser.add_argument('val1', nargs='*')
+        parser.add_argument('--file', type=str, default='')
+        parser.add_argument('--filename', type=str, default='')
+        parser.add_argument('--file-name', type=str, default='')
+        for flag in kwflags:
+            parser.add_argument(flag, type=str, default='')
+        parser.add_argument('val2', nargs='*')
+
+        data = str(data).strip()
+        first_line = '\n'.join(data.splitlines()[:1])
+        pattern = '(?i)file(_?name)?$'
+
+        result = DotObject(
+            is_parsed=False, is_data=False, data=data,
+            is_file=False, filename='', failure=''
+        )
+
+        try:
+            options = parser.parse_args(re.split(r' +', first_line))
+            result.is_parsed = True
+            for flag, val in vars(options).items():
+                if re.match(pattern, flag) and val.strip():
+                    result.is_file = True
+                    result.filename = val.strip()
+                else:
+                    if flag != 'val1' or flag != 'val2':
+                        if val.strip():
+                            result.is_data = True
+                            result.data = val.strip()
+                            return result
+
+            if result.val1 or result.val2:
+                result.is_data = True
+                return result
+            else:
+                result.is_parsed = False
+                result.failure = 'Invalid data'
+                return result
+
+        except Exception as ex:
+            result.failure = '{}: {}'.format(type(ex).__name__, ex)
+            result.is_parsed = False
+            return result
+
+
+class MiscOutput:
+    @classmethod
+    def execute_shell_command(cls, cmdline):
+        exit_code, output = subprocess.getstatusoutput(cmdline)
+        result = DotObject(
+            output=output,
+            exit_code=exit_code,
+            is_success=exit_code == ECODE.SUCCESS
+        )
+        return result
+
 
 class DictObject(dict):
     def __init__(self, *args, **kwargs):
@@ -494,3 +715,45 @@ class DotObject(DictObject):
     def __getitem__(self, key):
         value = super().__getitem__(key)
         return DotObject(value) if Misc.is_dict(value) else value
+
+
+def parse_template_result(test_data='', test_file='',
+                          template_data='', template_file=''):
+
+    if not any([test_data, test_file]):
+        failure = 'Neither test_data nor test_file CANT be empty.'
+        raise UtilsParsedTemplateError(failure)
+    else:
+        if not test_data:
+            if File.is_exist(test_file):
+                test_data = File.get_content(test_file)
+            else:
+                failure = '%r test data file is not existed.' % test_file
+                raise UtilsParsedTemplateError(failure)
+
+    if not any([template_data, template_file]):
+        failure = 'Neither template_data nor template_file CANT be empty.'
+        raise UtilsParsedTemplateError(failure)
+    else:
+        if template_data:
+            template = template_data
+        else:
+            if File.is_exist(template_file):
+                template = File.get_content(template_file)
+            else:
+                failure = '%r template file is not existed.' % template_file
+                raise UtilsParsedTemplateError(failure)
+
+    try:
+        stream = StringIO(template)
+        parser = TextFSM(stream)
+        rows = parser.ParseTextToDicts(test_data)
+
+        result = DotObject(
+            test_data=test_data, template=template,
+            records=rows, records_count=len(rows)
+        )
+        return result
+    except Exception as ex:
+        failure = 'BAD-TEMPLATE ({})'.format(Text(ex))
+        raise UtilsParsedTemplateError(failure)
